@@ -86,9 +86,15 @@ class UrlConnector:
         self.completed = False
 
     def get_source(self, document):
+        if 'headers' in document.metadata.connector_options:
+            opener = urllib.request.build_opener()
+            for header in document.metadata.connector_options['headers']:
+                opener.addheaders = [(header, document.metadata.connector_options['headers'][header])]
+            urllib.request.install_opener(opener)
         with tempfile.NamedTemporaryFile(delete=False) as tmp_file:
             urllib.request.urlretrieve(document.metadata.connector_options['url'], tmp_file.name)
-            return open(tmp_file.name, encoding='ISO-8859-1')
+
+            return open(tmp_file.name, 'rb')
 
     def __iter__(self):
         return self
