@@ -3,7 +3,6 @@ import os
 import uuid
 
 import msgpack
-from attrdict import AttrDict
 
 from kodexa.mixins import registry
 from kodexa.mixins.registry import get_mixin
@@ -370,10 +369,8 @@ class DefaultDocumentRender:
         out_list.append("{}[type:{}]{}".format(" " * (4 * level), node.type, self.mixins_to_text(node)))
 
         if node.content_parts:
-            print("Content Parts:")
             out_list.append("{}{}".format(" " * (4 * level), self.get_content_parts(node)))
 
-        print("Content:")
         out_list.append("{}{}".format(" " * (4 * level), node.content))
 
         for child in node.get_children():
@@ -550,7 +547,7 @@ class Document(object):
 
             >>> document.from_json()
         """
-        return Document.from_dict(json.loads(json_string, object_hook=AttrDict))
+        return Document.from_dict(json.loads(json_string))
 
     @staticmethod
     def from_msgpack(bytes):
